==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class KeystoneIdentityProviderFluentImpl<A extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>{
  public KeystoneIdentityProviderFluentImpl() {
  }
  public KeystoneIdentityProviderFluentImpl(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this.withCa(instance.getCa()); 
    this.withDomainName(instance.getDomainName()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withTlsClientKey(instance.getTlsClientKey()); 
    this.withUrl(instance.getUrl()); 
  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder ca;
  private java.lang.String domainName;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientCert;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientKey;
  private java.lang.String url;
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} return (A) this;
  }
  public java.lang.Boolean hasCa() {
    return this.ca != null;
  }
  public A withNewCa(java.lang.String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCa() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.CaNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.CaNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editCa() {
    return withNewCaLike(getCa());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa() {
    return withNewCaLike(getCa() != null ? getCa(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewCaLike(getCa() != null ? getCa(): item);
  }
  public java.lang.String getDomainName() {
    return this.domainName;
  }
  public A withDomainName(java.lang.String domainName) {
    this.domainName=domainName; return (A) this;
  }
  public java.lang.Boolean hasDomainName() {
    return this.domainName != null;
  }
  
  /**
   * Method is deprecated. use withDomainName instead.
   */
  @java.lang.Deprecated
  public A withNewDomainName(java.lang.String arg0) {
    return (A)withDomainName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert) {
    _visitables.get("tlsClientCert").remove(this.tlsClientCert);
    if (tlsClientCert!=null){ this.tlsClientCert= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientCert); _visitables.get("tlsClientCert").add(this.tlsClientCert);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientCert() {
    return this.tlsClientCert != null;
  }
  public A withNewTlsClientCert(java.lang.String name) {
    return (A)withTlsClientCert(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientKey() {
    return this.tlsClientKey!=null?this.tlsClientKey.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientKey() {
    return this.tlsClientKey!=null?this.tlsClientKey.build():null;
  }
  public A withTlsClientKey(io.fabric8.openshift.api.model.SecretNameReference tlsClientKey) {
    _visitables.get("tlsClientKey").remove(this.tlsClientKey);
    if (tlsClientKey!=null){ this.tlsClientKey= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientKey); _visitables.get("tlsClientKey").add(this.tlsClientKey);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientKey() {
    return this.tlsClientKey != null;
  }
  public A withNewTlsClientKey(java.lang.String name) {
    return (A)withTlsClientKey(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientKeyNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientKeyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey() {
    return withNewTlsClientKeyLike(getTlsClientKey());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey() {
    return withNewTlsClientKeyLike(getTlsClientKey() != null ? getTlsClientKey(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientKeyLike(getTlsClientKey() != null ? getTlsClientKey(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KeystoneIdentityProviderFluentImpl that = (KeystoneIdentityProviderFluentImpl) o;
    if (ca != null ? !ca.equals(that.ca) :that.ca != null) return false;
    if (domainName != null ? !domainName.equals(that.domainName) :that.domainName != null) return false;
    if (tlsClientCert != null ? !tlsClientCert.equals(that.tlsClientCert) :that.tlsClientCert != null) return false;
    if (tlsClientKey != null ? !tlsClientKey.equals(that.tlsClientKey) :that.tlsClientKey != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ca,  domainName,  tlsClientCert,  tlsClientKey,  url,  super.hashCode());
  }
  public class CaNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CaNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    CaNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withCa(builder.build());
    }
    public N endCa() {
      return and();
    }
    
  }
  public class TlsClientCertNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientCertNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withTlsClientCert(builder.build());
    }
    public N endTlsClientCert() {
      return and();
    }
    
  }
  public class TlsClientKeyNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientKeyNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientKeyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withTlsClientKey(builder.build());
    }
    public N endTlsClientKey() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class KeystoneIdentityProviderFluentImpl<A extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>{
  public KeystoneIdentityProviderFluentImpl() {
  }
  public KeystoneIdentityProviderFluentImpl(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this.withCa(instance.getCa()); 
    this.withDomainName(instance.getDomainName()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withTlsClientKey(instance.getTlsClientKey()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder ca;
  private java.lang.String domainName;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientCert;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientKey;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} return (A) this;
  }
  public java.lang.Boolean hasCa() {
    return this.ca != null;
  }
  public A withNewCa(java.lang.String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCa() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.CaNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.CaNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editCa() {
    return withNewCaLike(getCa());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa() {
    return withNewCaLike(getCa() != null ? getCa(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewCaLike(getCa() != null ? getCa(): item);
  }
  public java.lang.String getDomainName() {
    return this.domainName;
  }
  public A withDomainName(java.lang.String domainName) {
    this.domainName=domainName; return (A) this;
  }
  public java.lang.Boolean hasDomainName() {
    return this.domainName != null;
  }
  
  /**
   * Method is deprecated. use withDomainName instead.
   */
  @java.lang.Deprecated
  public A withNewDomainName(java.lang.String arg0) {
    return (A)withDomainName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert) {
    _visitables.get("tlsClientCert").remove(this.tlsClientCert);
    if (tlsClientCert!=null){ this.tlsClientCert= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientCert); _visitables.get("tlsClientCert").add(this.tlsClientCert);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientCert() {
    return this.tlsClientCert != null;
  }
  public A withNewTlsClientCert(java.lang.String name) {
    return (A)withTlsClientCert(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientKey() {
    return this.tlsClientKey!=null?this.tlsClientKey.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientKey() {
    return this.tlsClientKey!=null?this.tlsClientKey.build():null;
  }
  public A withTlsClientKey(io.fabric8.openshift.api.model.SecretNameReference tlsClientKey) {
    _visitables.get("tlsClientKey").remove(this.tlsClientKey);
    if (tlsClientKey!=null){ this.tlsClientKey= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientKey); _visitables.get("tlsClientKey").add(this.tlsClientKey);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientKey() {
    return this.tlsClientKey != null;
  }
  public A withNewTlsClientKey(java.lang.String name) {
    return (A)withTlsClientKey(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey() {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientKeyNestedImpl();
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl.TlsClientKeyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey() {
    return withNewTlsClientKeyLike(getTlsClientKey());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey() {
    return withNewTlsClientKeyLike(getTlsClientKey() != null ? getTlsClientKey(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientKeyLike(getTlsClientKey() != null ? getTlsClientKey(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KeystoneIdentityProviderFluentImpl that = (KeystoneIdentityProviderFluentImpl) o;
    if (ca != null ? !ca.equals(that.ca) :that.ca != null) return false;
    if (domainName != null ? !domainName.equals(that.domainName) :that.domainName != null) return false;
    if (tlsClientCert != null ? !tlsClientCert.equals(that.tlsClientCert) :that.tlsClientCert != null) return false;
    if (tlsClientKey != null ? !tlsClientKey.equals(that.tlsClientKey) :that.tlsClientKey != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ca,  domainName,  tlsClientCert,  tlsClientKey,  url,  additionalProperties,  super.hashCode());
  }
  public class CaNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CaNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    CaNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withCa(builder.build());
    }
    public N endCa() {
      return and();
    }
    
  }
  public class TlsClientCertNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientCertNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withTlsClientCert(builder.build());
    }
    public N endTlsClientCert() {
      return and();
    }
    
  }
  public class TlsClientKeyNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>> implements io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientKeyNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientKeyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) KeystoneIdentityProviderFluentImpl.this.withTlsClientKey(builder.build());
    }
    public N endTlsClientKey() {
      return and();
    }
    
  }
  
}
